@@ -290,6 +290,25 @@ module SiSU_DAL
         SiSU_Screen::Ansi.new(@opt.cmd,"dal -> #{cf.meta}").txt_grey if @opt.cmd =~/M/
       end
       dal.each {|s| dal_array << s}
+      if @opt.cmd =~/M/
+        dal_array.each do |obj|
+          if defined? obj.parent
+            if defined? obj.ln
+              if defined? obj.node
+                puts %{#{obj.ln}: #{obj.ocn} : #{obj.parent} : #{obj.node} - #{obj.lc}}
+              else
+                puts %{#{obj.ln}: #{obj.ocn} : #{obj.parent}}
+              end
+            else
+              if defined? obj.node
+                puts %{   #{obj.ocn} : #{obj.parent} : #{obj.node} - #{obj.lc}}
+              else
+                puts %{   #{obj.ocn} : #{obj.parent}}
+              end
+            end
+          end
+        end
+      end
       dal_array
     end
     def read_fnm
