@@ -332,7 +332,7 @@ module SiSU_DAL_Syntax
       dob
     end
     def fontface(dob)
-      leader=/^|#{Mx[:gl_c]}|\s+|['"]|[#{Mx[:nbsp]}#{Mx[:fa_o_c]}#{Mx[:fa_c]}#{Mx[:lnk_o]}#{Mx[:br_nl]}#{Mx[:br_line]}#{Mx[:br_paragraph]}#{Mx[:tc_c]}#{Mx[:tc_p]}]|[\(\[\{]|\>/
+      leader=/^|#{Mx[:gl_c]}|\s+|['"]|[#{Mx[:nbsp]}#{Mx[:fa_o_c]}#{Mx[:fa_c]}#{Mx[:lnk_o]}#{Mx[:br_nl]}#{Mx[:br_line]}#{Mx[:br_paragraph]}#{Mx[:tc_c]}#{Mx[:tc_p]}]|[\(\[\{]|[、。]|\>/
       dob=fontface_lines(dob,leader)
       dob.obj=dob.obj.gsub(/(#{leader})\*\{(.+?)\}\*/m,
           "\\1#{@emph[:o]}\\2#{@emph[:c]}").                                                                                                                             #emphasis
