@@ -360,6 +360,30 @@ module SiSU_Param_Make
           ? @h['texpdf_font_mono']
           : @env.font.texpdf.mono
         end
+        def cjk
+          @h['texpdf_font_cjk'] \
+          && (@h['texpdf_font_cjk']=~/\S{3,}/) \
+          ? @h['texpdf_font_cjk']
+          : @env.font.texpdf.cjk
+        end
+        def cjk_zh
+          @h['texpdf_font_cjk_zh'] \
+          && (@h['texpdf_font_cjk_zh']=~/\S{3,}/) \
+          ? @h['texpdf_font_cjk_zh']
+          : @env.font.texpdf.cjk_zh
+        end
+        def cjk_ja
+          @h['texpdf_font_cjk_ja'] \
+          && (@h['texpdf_font_cjk_ja']=~/\S{3,}/) \
+          ? @h['texpdf_font_cjk_ja']
+          : @env.font.texpdf.cjk_ja
+        end
+        def cjk_ko
+          @h['texpdf_font_cjk_ko'] \
+          && (@h['texpdf_font_cjk_ko']=~/\S{3,}/) \
+          ? @h['texpdf_font_cjk_ko']
+          : @env.font.texpdf.cjk_ko
+        end
         self
       end
       def promo
