@@ -104,7 +104,7 @@ module SiSU_Plaintext
         #wrap_width=(defined? md.make.plaintext_wrap) ? md.make.plaintext_wrap : 78
         SiSU_Plaintext::Source::Scroll.new(md,dal_array,wrap_width).songsheet
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
