@@ -66,7 +66,7 @@ module  SiSU_CGI_PgSQL
   class SearchPgSQL < CGI_Common
     def initialize(opt,webserv)
       @opt,@webserv=opt,webserv
-      @cX=SiSU_Screen::Ansi.new(opt.cmd).cX
+      @cX=SiSU_Screen::Ansi.new(opt.act[:color_state][:set]).cX
       @env=SiSU_Env::InfoEnv.new('',opt)
       @sys=SiSU_Env::SystemCall.new
       @db=SiSU_Env::InfoDb.new
@@ -173,13 +173,13 @@ module  SiSU_CGI_PgSQL
               sudo chmod -v 755  /usr/lib/cgi-bin/#{@cgi_file_name}
           WOK
         end
-        SiSU_Screen::Ansi.new(@opt.cmd,a).warn
+        SiSU_Screen::Ansi.new(opt.act[:color_state][:set],a).warn
         a=<<-WOK
               #{@env.webserv_base_cgi(@opt)}/cgi-bin/#{@cgi_file_name}
         WOK
-        SiSU_Screen::Ansi.new(@opt.cmd,a).print_blue
+        SiSU_Screen::Ansi.new(opt.act[:color_state][:set],a).print_blue
         a="\n\t(to create and populate postgresql database see 'man sisu' and in particular the --pg option)\n\t[the database to be used for this directory (#{@db.psql.db}) will have to be created manually if it does not exist,\n\tusing postgresql tools directly: 'createdb #{@db.psql.db}' for a list of existing databases try 'psql --list']"
-        SiSU_Screen::Ansi.new(@opt.cmd,a).txt_grey
+        SiSU_Screen::Ansi.new(opt.act[:color_state][:set],a).txt_grey
       else puts 'failed in attempt to write #{@cgi_file_name} to present directory,  is directory writable?'
       end
     end
