@@ -96,29 +96,29 @@ module SiSU_Initialize
       @pwd,@home=Dir.pwd,@env.path.home
     end
     def make_homepage
-      SiSU_Screen::Ansi.new(@opt.cmd,'invert','Make homepage','').colorize unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'invert','Make homepage','').colorize unless @opt.act[:quiet][:set]==:on
       SiSU_Env::CreateSite.new(@opt.cmd).homepage
     end
     def cp_local_images
-      SiSU_Screen::Ansi.new(@opt.cmd,'invert','Copy images','').colorize unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'invert','Copy images','').colorize unless @opt.act[:quiet][:set]==:on
       SiSU_Env::CreateSite.new(@opt.cmd).cp_local_images
       SiSU_Env::CreateSite.new(@opt.cmd).cp_webserver_images_local #this should not have been necessary
       SiSU_Env::CreateSite.new(@opt.cmd).cp_base_images #base images (nav etc.) used by all html
     end
     def cp_external_images
-      SiSU_Screen::Ansi.new(@opt.cmd,'invert','Copy external images','').colorize if @opt.cmd =~/V/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'invert','Copy external images','').colorize if @opt.act[:verbose_plus][:set]==:on
       SiSU_Env::CreateSite.new(@opt.cmd).cp_external_images
     end
     def cp_webserver_images
-      SiSU_Screen::Ansi.new(@opt.cmd,'invert','Copy webserver/output file images','').colorize unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'invert','Copy webserver/output file images','').colorize unless @opt.act[:quiet][:set]==:on
       SiSU_Env::CreateSite.new(@opt.cmd).cp_webserver_images
     end
     def css
-      SiSU_Screen::Ansi.new(@opt.cmd,'invert','Configuring CSSs','').colorize unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'invert','Configuring CSSs','').colorize unless @opt.act[:quiet][:set]==:on
       SiSU_Env::CreateSite.new(@opt.cmd).cp_css
     end
     def dtd
-      SiSU_Screen::Ansi.new(@opt.cmd,'invert','Configuring DTDs','').colorize unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'invert','Configuring DTDs','').colorize unless @opt.act[:quiet][:set]==:on
       @rxng=SiSU_Relaxng::RelaxNG.new
       @path.each { |d| FileUtils::mkdir_p(d[1]) unless FileTest.directory?(d[1]) }
       #ugly code, sort later
