@@ -63,20 +63,23 @@
 #Ax,Xx,Mx,Rx,Hx,Dx,Px,Ep,Db,Gt,Tex=Array.new(11){{}}
 YEAR='2013'
 Sfx={
-  txt:        '.txt',
-  html:       '.html',
-  xhtml:      '.xhtml',
-  xml:        '.xml',
-  xml_sax:    '.sax.xml',
-  xml_dom:    '.dom.xml',
-  epub:       '.epub',
-  epub_xhtml: '.xhtml',
-  odt:        '.odt',
-  pdf:        '.pdf',
-  manpage:    '.1',
-  info:       '.info',
-  texinfo:    '.texinfo',
-  sql:        '.sql.db',
+  txt:                       '.txt',
+  html:                      '.html',
+  xhtml:                     '.xhtml',
+  xml:                       '.xml',
+  xml_sax:                   '.sax.xml',
+  xml_dom:                   '.dom.xml',
+  xml_scaffold:              '.scaffold.xml',
+  xml_scaffold_structure_sisu:     '.scaffold.sisu.xml',
+  xml_scaffold_structure_collapse: '.scaffold.collapse.xml',
+  epub:                      '.epub',
+  epub_xhtml:                '.xhtml',
+  odt:                       '.odt',
+  pdf:                       '.pdf',
+  manpage:                   '.1',
+  info:                      '.info',
+  texinfo:                   '.texinfo',
+  sql:                       '.sql.db',
 }
 Ax={
   tab:                       "\t",
