@@ -690,24 +690,24 @@ module SiSU_DAL_DocumentStructureExtract
       end
       if @md.flag_endnotes
         tuned_file << @pb
-        h={ ln: 2, obj: 'Endnotes', autonum_: false }
+        h={ ln: 2, lc: 2, obj: 'Endnotes', autonum_: false }
         tuned_file << SiSU_DAL_DocumentStructure::ObjectHeading.new.heading_insert(h)
-        h={ ln: 4, obj: 'Endnotes', name: 'endnotes', autonum_: false }
+        h={ ln: 4, lc: 3, obj: 'Endnotes', name: 'endnotes', autonum_: false }
         tuned_file << SiSU_DAL_DocumentStructure::ObjectHeading.new.heading_insert(h)
         h={ obj: 'Endnotes' }
       end
       if @md.book_idx
         tuned_file << @pb
-        h={ ln: 2, obj: 'Index', autonum_: false }
+        h={ ln: 2, lc: 2, obj: 'Index', autonum_: false }
         tuned_file << SiSU_DAL_DocumentStructure::ObjectHeading.new.heading_insert(h)
-        h={ ln: 4, obj: 'Index', name: 'book_index', autonum_: false }
+        h={ ln: 4, lc: 3, obj: 'Index', name: 'book_index', autonum_: false }
         tuned_file << SiSU_DAL_DocumentStructure::ObjectHeading.new.heading_insert(h)
         h={ obj: 'Index' }
       end
       tuned_file << @pb
-      h={ ln: 2, obj: 'Metadata', autonum_: false, ocn_: false }
+      h={ ln: 2, lc: 2, obj: 'Metadata', autonum_: false, ocn_: false }
       tuned_file << SiSU_DAL_DocumentStructure::ObjectHeading.new.heading_insert(h)
-      h={ ln: 4, obj: 'SiSU Metadata, document information', name: 'metadata', autonum_: false, ocn_: false }
+      h={ ln: 4, lc: 3, obj: 'SiSU Metadata, document information', name: 'metadata', autonum_: false, ocn_: false }
       tuned_file << SiSU_DAL_DocumentStructure::ObjectHeading.new.heading_insert(h)
       h={ obj: 'eof' }
       meta=SiSU_DAL_DocumentStructure::ObjectMetadata.new.metadata(@metadata)
