@@ -288,7 +288,9 @@ module SiSU_DAL_Numbering
       tags={}
       art_filename_auto=1
       @counter=1
-      if not @md.seg_autoname_safe and @md.opt.cmd =~/[MV]/
+      if not @md.seg_autoname_safe \
+      and (@md.opt.act[:verbose_plus][:set]==:on \
+      || @md.opt.act[:maintenance][:set]==:on)
         puts 'manual segment names, numbers used as names, risk warning (segmented html)'
       end
       ocn_html_seg=[]
@@ -311,7 +313,9 @@ module SiSU_DAL_Numbering
               dob.name=possible_seg_name
               dob.tags=[dob.name,dob.tags].flatten if dob.name !~/^\d+$/
               @md.seg_names << possible_seg_name
-            else puts 'warn, there may be a conflicting numbering scheme' if @md.opt.cmd =~/[VM]/
+            elsif (@md.opt.act[:verbose_plus][:set]==:on \
+            or @md.opt.act[:maintenance][:set]==:on)
+              puts 'warn, there may be a conflicting numbering scheme'
             end
           end
           if dob.ln==4 \
@@ -407,7 +411,10 @@ module SiSU_DAL_Numbering
     end
     def set_heading_top(data)                                                          #% make sure no false positives
       unless @md.set_heading_top
-        puts "\tdocument contains no top level heading, (will have to manufacture one)" if @md.opt.cmd =~/[MV]/
+        if (@md.opt.act[:verbose_plus][:set]==:on \
+        or @md.opt.act[:maintenance][:set]==:on)
+          puts "\tdocument contains no top level heading, (will have to manufacture one)"
+        end
         @tuned_file=[]
         data.each do |t_o|
           unless @md.set_heading_top
@@ -431,7 +438,10 @@ module SiSU_DAL_Numbering
     end
     def set_heading_seg(data)                                                          #% make sure no false positives
       unless @md.set_heading_seg
-        puts "\tdocument contains no segment level, (will have to manufacture one)" if @md.opt.cmd =~/[MV]/
+        if (@md.opt.act[:verbose_plus][:set]==:on \
+        or @md.opt.act[:maintenance][:set]==:on)
+          puts "\tdocument contains no segment level, (will have to manufacture one)"
+        end
         @tuned_file=[]
         data.each do |dob|
           unless @md.set_heading_seg
@@ -452,7 +462,10 @@ module SiSU_DAL_Numbering
     end
     def set_header_title(data)                                                         #% make sure no false positives
       unless @md.set_header_title
-        puts "\t no document title provided, (will have to manufacture one)" if @md.opt.cmd =~/[MV]/
+        if (@md.opt.act[:verbose_plus][:set]==:on \
+        or @md.opt.act[:maintenance][:set]==:on)
+          puts "\t no document title provided, (will have to manufacture one)"
+        end
         @tuned_file=[]
         data.each do |t_o|
           unless @md.set_header_title
