@@ -149,7 +149,7 @@ module SiSU_DbDrop
           end
         end
         def base                                                             #% drop base indexes
-          print "\n          drop documents common indexes\n" unless @opt.cmd =~/q/
+          print "\n          drop documents common indexes\n" unless @opt.act[:quiet][:set]==:on
           sql_arr=[
             %{DROP INDEX idx_title;},
             %{DROP INDEX idx_author;},
@@ -176,7 +176,7 @@ module SiSU_DbDrop
           conn_execute_array(sql_arr)
         end
         def text                                                             #% drop TEXT indexes, sqlite
-          print "\n          drop documents TEXT indexes\n" unless @opt.cmd =~/q/
+          print "\n          drop documents TEXT indexes\n" unless @opt.act[:quiet][:set]==:on
           sql_arr=[
             %{DROP INDEX idx_clean;},
             %{DROP INDEX idx_endnote},
