@@ -112,11 +112,15 @@ module SiSU_DbRemove
             @conn.execute(s)
           end
         end
-        if @opt.cmd =~/M/
-          @file.puts sql_entry if @opt.cmd =~/M/
+        if @opt.act[:maintenance][:set]==:on
+          @file.puts sql_entry
         end
       else
-        SiSU_Screen::Ansi.new(@opt.cmd,"no such file in database #{@db.psql.db}::#{@opt.fns}").puts_grey if @opt.cmd =~/vVM/
+        if (@opt.act[:verbose][:set]==:on \
+        || @opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on)
+          SiSU_Screen::Ansi.new(@opt.cmd,"no such file in database #{@db.psql.db}::#{@opt.fns}").puts_grey
+        end
       end
     end
   end
