@@ -331,6 +331,14 @@ module SiSU
           require_relative 'xhtml'                     #  xhtml.rb
           SiSU_XHTML::Source.new(@opt).read
         end
+        if @opt.act[:xml_scaffold_structure_sisu][:set]==:on #% --xml-scaffold --xml-scaffold-sisu
+          require_relative 'xml_scaffold_structure_sisu' #  xml_scaffold_structure_sisu.rb
+          SiSU_XML_Scaffold_Structure_Sisu::Source.new(@opt).read
+        end
+        if @opt.act[:xml_scaffold_structure_collapse][:set]==:on #% --xml-scaffold-collapse
+          require_relative 'xml_scaffold_structure_collapsed' # xml_scaffold_structure_collapsed.rb
+          SiSU_XML_Scaffold_Structure_Collapse::Source.new(@opt).read
+        end
         if @opt.act[:xml_sax][:set]==:on               #% --xml-sax, -x xml sax type
           require_relative 'xml'                       #  xml.rb
           SiSU_XML_SAX::Source.new(@opt).read
@@ -633,6 +641,8 @@ module SiSU
         || @opt.act[:odt][:set]==:on \
         || @opt.act[:xml_sax][:set]==:on \
         || @opt.act[:xml_dom][:set]==:on \
+        || @opt.act[:xml_scaffold_structure_sisu][:set]==:on \
+        || @opt.act[:xml_scaffold_structure_collapse][:set]==:on \
         || @opt.act[:pdf][:set]==:on \
         || @opt.act[:pdf_p][:set]==:on \
         || @opt.act[:pdf_l][:set]==:on \
