@@ -396,6 +396,20 @@ module SiSU_Manifest
           id,file='XML DOM',@f.base_filename.xml_dom
           summarize(id,file,pth,rel,url)
         end
+        if FileTest.file?(@f.place_file.xml_scaffold_structure_sisu.dir)==true
+          pth=@f.output_path.xml_scaffold_structure_sisu.dir
+          rel=@f.output_path.xml_scaffold_structure_sisu.rel_sm
+          url=@f.output_path.xml_scaffold_structure_sisu.url
+          id,file='XML Scaffold sisu structure',@f.base_filename.xml_scaffold_structure_sisu
+          summarize(id,file,pth,rel,url)
+        end
+        if FileTest.file?(@f.place_file.xml_scaffold_structure_collapse.dir)==true
+          pth=@f.output_path.xml_scaffold_structure_collapse.dir
+          rel=@f.output_path.xml_scaffold_structure_collapse.rel_sm
+          url=@f.output_path.xml_scaffold_structure_collapse.url
+          id,file='XML Scaffold collapsed structure',@f.base_filename.xml_scaffold_structure_collapse
+          summarize(id,file,pth,rel,url)
+        end
         if FileTest.file?(@f.place_file.info.dir)==true
           pth=@f.output_path.texinfo.dir
           rel=@f.output_path.texinfo.rel_sm
