@@ -85,14 +85,21 @@ module SiSU_Manpage
       begin
         @md=SiSU_Param::Parameters.new(@opt).get
         @env=SiSU_Env::InfoEnv.new(@opt.fns)
-        tool=(@opt.cmd =~/[MVv]/) \
+        tool=(@opt.act[:verbose][:set]==:on \
+        || @opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on) \
         ?  "#{@env.program.text_editor} #{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}"
         : "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
-        @opt.cmd=~/[MVvz]/ \
+        (@opt.act[:verbose][:set]==:on \
+        || @opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on) \
         && @opt.cmd !~/q/ \
-        ? SiSU_Screen::Ansi.new(@opt.cmd,'Manpage',tool).green_hi_blue
-        : SiSU_Screen::Ansi.new(@opt.cmd,'Manpage',tool).green_title_hi
-        SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}").flow if @opt.cmd =~/[MV]/
+        ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Manpage',tool).green_hi_blue
+        : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Manpage',tool).green_title_hi
+        if (@opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on)
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}").flow
+        end
         @dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
         SiSU_Manpage::Source::Scroll.new(@md,@dal_array).songsheet
       rescue
