@@ -861,6 +861,12 @@ module SiSU_Commandline
         || mod.inspect =~/"--xml-dom"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
+        act[:xml_scaffold_structure_sisu]=mod.inspect =~/"--xml-scaffold"|"--xml-scaffold-sisu"/ \
+        ? { bool: true, set: :on }
+        : { bool: false, set: :na }
+        act[:xml_scaffold_structure_collapse]=mod.inspect =~/"--xml-scaffold-collapse"/ \
+        ? { bool: true, set: :on }
+        : { bool: false, set: :na }
         act[:xhtml]=(cmd =~/b/ \
         || mod.inspect =~/"--xhtml"/) \
         ? { bool: true, set: :on }
@@ -979,7 +985,9 @@ module SiSU_Commandline
         || act[:sisupod][:set]==:on \
         || act[:concordance][:set]==:on \
         || act[:xml_dom][:set]==:on \
-        || act[:xml_sax][:set]==:on )
+        || act[:xml_sax][:set]==:on \
+        || act[:xml_scaffold_structure_sisu][:set]==:on \
+        || act[:xml_scaffold_structure_collapse][:set]==:on )
           { bool: true, set: :on }
           #if cmd !~/[mn]/
           #  extra+=if cmd =~/[abegHhIiLNOoPpQTtwXxyz]/ \
@@ -1021,7 +1029,9 @@ module SiSU_Commandline
         || act[:sisupod][:set]==:on \
         || act[:concordance][:set]==:on \
         || act[:xml_dom][:set]==:on \
-        || act[:xml_sax][:set]==:on )
+        || act[:xml_sax][:set]==:on \
+        || act[:xml_scaffold_structure_sisu][:set]==:on \
+        || act[:xml_scaffold_structure_collapse][:set]==:on )
           { bool: true, set: :on }
           ##      if cmd !~/y/
           ##        extra+=if cmd =~/[abeHhIiNopQSstwXxz]/ \
