@@ -78,7 +78,7 @@ module SiSU_Sitemaps
         @sys=SiSU_Env::SystemCall.new
         fn_set_lang=SiSU_Env::StandardiseLanguage.new(@opt.lng).language
         @fn=SiSU_Env::EnvCall.new(@opt.fns).lang(fn_set_lang[:c])
-        if @opt.cmd =~/Y/
+        if @opt.act[:sitemap][:set]==:on
           @md=SiSU_Param::Parameters.new(@opt).get
           @trans=SiSU_XML_Munge::Trans.new(@md) #check @md is required
           @env=SiSU_Env::InfoEnv.new(@md.fns)
@@ -91,7 +91,7 @@ module SiSU_Sitemaps
           @sitemap_idx_fn='sitemapindex.xml'
           @env=SiSU_Env::InfoEnv.new
           output_idx(sitemap_index)
-          SiSU_Screen::Ansi.new(@opt.cmd,"sitemap index:","#{@env.path.output}/#{@sitemap_idx_fn}").result unless @opt.cmd =~/q/
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"sitemap index:","#{@env.path.output}/#{@sitemap_idx_fn}").result unless @opt.act[:quiet][:set]==:on
         end
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
