@@ -103,13 +103,17 @@ module SiSU_TexInfo
     end
     def song
       begin
-        tool=(@opt.cmd =~/[MVv]/) \
+        tool=(@opt.act[:verbose][:set]==:on \
+        || @opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on) \
         ?  "#{@env.program.texinfo} #{@md.file.output_path.texinfo.dir}/#{@md.file.base_filename.info}"
         : "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
-        @opt.cmd=~/[MVvz]/ \
-        && @opt.cmd !~/q/ \
-        ? SiSU_Screen::Ansi.new(@opt.cmd,'TexInfo',tool).green_hi_blue
-        : SiSU_Screen::Ansi.new(@opt.cmd,'TexInfo',tool).green_title_hi
+        (@opt.act[:verbose][:set]==:on \
+        || @opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on) \
+        && ! @opt.act[:quiet][:set]==:on \
+        ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'TexInfo',tool).green_hi_blue
+        : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'TexInfo',tool).green_title_hi
         @md=SiSU_Param::Parameters.new(@opt).get
         directories
         @marshalfile=SiSU_Env::InfoFile.new(@opt.fns).marshal.dal_content
@@ -123,7 +127,7 @@ module SiSU_TexInfo
         tex_array=@@tuned_file
         TeXinfoMake.new(@md,tex_array).songsheet
         tex_array=''
-      rescue; STDERR.puts SiSU_Screen::Ansi.new(@opt.cmd,$!,$@).rescue
+      rescue; STDERR.puts SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],$!,$@).rescue
       ensure
       end
     end
@@ -151,7 +155,7 @@ module SiSU_TexInfo
         output(doc_txt)
         makeinfo #KEEP reinstate when fixed #%
         place_info
-      rescue; STDERR.puts SiSU_Screen::Ansi.new(@md.opt.cmd,$!,$@).rescue
+      rescue; STDERR.puts SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],$!,$@).rescue
       ensure
       end
     end
@@ -384,7 +388,7 @@ module SiSU_TexInfo
     def output(data)
       filename_texinfo=%{#{@env.processing_path.texi}/#{@md.fnb}.texinfo}
       file_texinfo=File.new(filename_texinfo,'w+')
-      puts filename_texinfo if @md.opt.cmd =~/M/
+      puts filename_texinfo if @md.opt.act[:maintenance][:set]==:on
       data.each {|s| (file_texinfo.puts s,"\n") if s}
       file_texinfo.close
     end
