@@ -483,7 +483,7 @@ module SiSU_TeX_Pdf
         @txt.gsub!(/<:=\s*(\S+?)\s*>/,
           "\\includegraphics*[width=11pt]{#{dir.path.image_source_include}/c_\\1.png}")
       else
-        SiSU_Screen::Ansi.new(@md.opt.cmd,"ERROR - image:",%{"#{image}" missing},"search path: #{dir.path.image_source_include}").error2 unless @md.opt.cmd =~/q/
+        SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"ERROR - image:",%{"#{image}" missing},"search path: #{dir.path.image_source_include}").error2 unless @md.opt.act[:quiet][:set]==:on
         @txt.gsub!(/#{Mx[:lnk_o]}\S+\.(png|jpg|gif).+?#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'') # fragile match operator\\ fragile !
       end
     end
@@ -626,7 +626,7 @@ module SiSU_TeX_Pdf
               hsp="\n{\\color{mywhite} .}&~\n" # ~ character for hardspace
               caption=(c ?  "{\\\\\ \n\\begin{scriptsize}#{hsp*3}#{c}\\end{scriptsize}&}" : '')
             elsif images_hash[ps] =~/#{Mx[:lnk_o]}\s*(\S+\.?\.(?:png|jpg|gif))/m
-              SiSU_Screen::Ansi.new(@md.opt.cmd,%{document built without image: "#{$1}" as image dimensions not provided (either image not found or neither imagemagick nor graphicsmagick is installed)?\n}).print_grey #unless @opt.cmd =~/q/
+              SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],%{document built without image: "#{$1}" as image dimensions not provided (either image not found or neither imagemagick nor graphicsmagick is installed)?\n}).print_grey #unless @md.opt.act[:quiet][:set]==:on
               images_hash[ps].gsub!(/#{Mx[:lnk_o]}\s*(\S+\.?\.(?:png|jpg|gif))/,'[image]')
             end
             if image #most images fc etc. #% clean up !
@@ -678,7 +678,7 @@ module SiSU_TeX_Pdf
                 end
                 images_hash[ps]
               else
-                SiSU_Screen::Ansi.new(@md.opt.cmd,"ERROR - image:",%{"#{image}" missing},"search locations: #{dir.path.image_source_include_local},#{dir.path.image_source_include_remote} and #{dir.path.image_source_include}").error2 unless @md.opt.cmd =~/q/
+                SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"ERROR - image:",%{"#{image}" missing},"search locations: #{dir.path.image_source_include_local},#{dir.path.image_source_include_remote} and #{dir.path.image_source_include}").error2 unless @md.opt.act[:quiet][:set]==:on
                 if images_hash[ps] =~url_image_rgx \
                 or images_hash[ps] =~image_rgx
                   images_hash[ps]=''
@@ -794,11 +794,52 @@ module SiSU_TeX_Pdf
         @md.make.texpdf_font.mono
       else @env.font.texpdf.mono
       end
-      # you may wish to check selected font against avaiable fonts:
+      texpdf_font_cjk=if @md.opt.lng =~/zh/ \
+      and defined? @md.make.texpdf_font.cjk_zh \
+      and not @md.make.texpdf_font.cjk_zh.nil? \
+      and @md.make.texpdf_font.cjk_zh=~/\S{3,}/
+        @md.make.texpdf_font.cjk_zh
+      elsif @md.opt.lng =~/ja/ \
+      and defined? @md.make.texpdf_font.cjk_ja \
+      and not @md.make.texpdf_font.cjk_ja.nil? \
+      and @md.make.texpdf_font.cjk_ja=~/\S{3,}/
+        @md.make.texpdf_font.cjk_ja
+      elsif @md.opt.lng =~/ko/ \
+      and defined? @md.make.texpdf_font.cjk_ko \
+      and not @md.make.texpdf_font.cjk_ko.nil? \
+      and @md.make.texpdf_font.cjk_ko=~/\S{3,}/
+        @md.make.texpdf_font.cjk_ko
+      elsif @md.opt.lng =~/(?:zh|ja|ko)/ \
+      and defined? @md.make.texpdf_font.cjk \
+      and not @md.make.texpdf_font.cjk.nil? \
+      and @md.make.texpdf_font.cjk=~/\S{3,}/
+        @md.make.texpdf_font.cjk
+      else
+        case @md.opt.lng
+        when /zh/; @env.font.texpdf.cjk_zh
+        when /ja/; @env.font.texpdf.cjk_ja
+        when /ko/; @env.font.texpdf.cjk_ko
+        else @env.font.texpdf.cjk
+        end
+      end
+      # you may wish to check selected font against available fonts:
       # fc-list :outline -f "%{family}\n"
+      # fc-list :lang=ja
       case @tex2pdf
       when /xe/
-        <<-WOK
+        if @md.opt.lng =~/(?:zh|ja|ko)/
+          <<-WOK
+\\usepackage{ucs, fontspec, xltxtra, xunicode, xeCJK}
+\\setmainCJKlanguage{#{tex_head_lang[:mainlang]}}
+\\setCJKmainfont{#{texpdf_font_cjk}}
+\\XeTeXlinebreaklocale "#{tex_head_lang[:mainlang]}"
+\\XeTeXlinebreakskip = 0pt plus 1pt
+\\setotherlanguage{#{tex_head_lang[:otherlang]}}
+\\setmainfont{#{texpdf_font}}
+\\setmonofont[Scale=0.85]{#{texpdf_font_mono}}
+          WOK
+        else
+          <<-WOK
 \\usepackage{polyglossia, ucs, fontspec, xltxtra, xunicode}
 \\setmainlanguage{#{tex_head_lang[:mainlang]}}
 \\setotherlanguage{#{tex_head_lang[:otherlang]}}
@@ -806,7 +847,8 @@ module SiSU_TeX_Pdf
 \\setmonofont[Scale=0.85]{#{texpdf_font_mono}}
 % \\setsansfont{#{texpdf_font_sans}}
 % \\setromanfont{#{texpdf_font_serif}}
-        WOK
+          WOK
+        end
       when /pdf/
         if @md.file_encoding =~ /iso-?8859/i                                   #% iso8859
           <<-WOK
@@ -1518,7 +1560,7 @@ Generated by \\href{http://www.jus.uio.no/sisu}{SiSU www.jus.uio.no/sisu } \\\\
       sisu_ico=if FileTest.file?("#{dir.path.image_source_include}/sisu.png")
         "\\includegraphics*[width=60pt]{#{dir.path.image_source_include}/sisu.png}"
       else
-        SiSU_Screen::Ansi.new(@md.opt.cmd,'WARNING - image directory or image(s) missing:', %{"#{dir.path.image_source_include}"} ).warn unless @md.opt.cmd =~/q/
+        SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'WARNING - image directory or image(s) missing:', %{"#{dir.path.image_source_include}"} ).warn unless @md.opt.act[:quiet][:set]==:on
         " SiSU "
       end
       url=@md.fnb.gsub(/(?:\\)*([$&~%_#}{^])/,'\\\\\1')
