@@ -116,6 +116,8 @@ module SiSU_Urls
         't --txt (Plain-text (endnotes))'=>@fn[:plain],
         'x --xml-sax (XML sax type)'=>@fn[:sax],
         'X --xml-dom (XML dom type)'=>@fn[:dom],
+        '  --xml-scaffold-sisu (XML scaffold)'=>@fn[:xml_scaffold_structure_sisu],
+        '  --xml-scaffold-collapse (XML scaffold)'=>@fn[:xml_scaffold_structure_collapse],
         'Q --qrcode (QR Code jpg)'=>@fn[:qrcode],
         'y --manifest (Manifest, html)'=>@fn[:manifest],
         'Y (Sitemap, xml)'=>@fn[:sitemap],
@@ -209,6 +211,12 @@ module SiSU_Urls
         def dom(x)
           SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}").result
         end
+        def scaffold_structure_sisu(x)
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_scaffold_structure_sisu.dir}/#{@md.file.base_filename.xml_scaffold_structure_sisu}").result
+        end
+        def scaffold_structure_collapse(x)
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_scaffold_structure_collapse.dir}/#{@md.file.base_filename.xml_scaffold_structure_collapse}").result
+        end
         def sitemap(x) #BROKEN
           SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.sitemaps.dir}/#{@md.file.base_filename.sitemap}").result
         end
@@ -398,6 +406,14 @@ module SiSU_Urls
               and @opt.act[:xml_sax][:set]==:on
                 show.xml.sax(x)
               end
+              if x=~/--xml-scaffold-sisu\b/ \
+              and @opt.act[:xml_scaffold_structure_sisu][:set]==:on
+                show.xml.scaffold_structure_sisu(x)
+              end
+              if x=~/--xml-scaffold-collapse\b/ \
+              and @opt.act[:xml_scaffold_structure_collapse][:set]==:on
+                show.xml.scaffold_structure_collapse(x)
+              end
               if x=~/--qrcode\b/ \
               and @opt.act[:qrcode][:set]==:on
                 show.qrcode(x)
