@@ -1001,7 +1001,7 @@ WOK
         else nil
         end
       else
-        if @md.opt.cmd =~/M/
+        if @md.opt.act[:maintenance][:set]==:on
           p __FILE__ << ':' << __LINE__.to_s
           p t_o.class
           p caller
