@@ -71,14 +71,14 @@ module SiSU_Zap
       zap_path="#{@env.path.output}/#{@env.fnb}"
       z=SiSU_Env::CleanOutput.new(@opt)
       if SiSU_Env::InfoSettings.new.permission?('zap')
-        unless @opt.cmd =~/q/
-          tell=SiSU_Screen::Ansi.new(@opt.cmd,"Clean files related to processing #{@opt.cmd} ->","#{@opt.fns} -> #{zap_path}")
+        unless @opt.act[:quiet][:set]==:on
+          tell=SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"Clean files related to processing #{@opt.cmd} ->","#{@opt.fns} -> #{zap_path}")
           tell.warn
         end
         z.zap.remove_output
       else
-        unless @opt.cmd =~/q/
-          tell=SiSU_Screen::Ansi.new(@opt.cmd,'use of -Z (zap) has not enabled in sisurc.yml')
+        unless @opt.act[:quiet][:set]==:on
+          tell=SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'use of -Z (zap) has not enabled in sisurc.yml')
           tell.warn
         end
       end
